@@ -95,7 +95,7 @@ new_project <- function(project = "new", path = getwd(),
     if(file.exists(file.path(path, project))) {
         message(paste0("\"", paste0(path, "/", project), 
             "\" already exists:\nDo you want to overwrite?\n"))
-        ans <- menu(c("Yes", "No")) 
+        ans <- utils::menu(c("Yes", "No")) 
         if (ans == "2") {
             stop("new_project aborted")
         } else {
@@ -200,7 +200,7 @@ new_project <- function(project = "new", path = getwd(),
     cat(info, file=paste0(y[[7]], "/", "CONTACT_INFO"))
 
     ## Create a KEY.csv codebook
-    write.csv(data.frame(person=""), file=paste0(y[[2]], "/", "KEY.csv"), 
+    utils::write.csv(data.frame(person=""), file=paste0(y[[2]], "/", "KEY.csv"), 
         row.names = FALSE)
  
     ## Copy .Rprofile to main directory
